# scoutos-python

ScoutOS Python SDK

## Requirements

- Python ^3.10

## Installation

- With [pip](https://pip.pypa.io/en/stable/): `pip install scoutos`
- With [poetry](https://python-poetry.org): `poetry add scoutos`
